@@ -18,6 +18,7 @@ class JoinGroupCall(SpawnProcess):
             chat_id: int,
             file_path: str,
             bitrate: int = 48000,
+            invite_hash: str = None,
             join_as: InputPeer = None,
             stream_type: StreamType = None,
     ):
@@ -41,22 +42,23 @@ class JoinGroupCall(SpawnProcess):
                 self._spawn_process(
                     requests.post,
                     (
-                        f'http://'
+                        'http://'
                         f'{self.pytgcalls._host}:'
                         f'{self.pytgcalls._port}/'
-                        f'api_internal',
+                        'api_internal',
                         json.dumps({
                             'action': 'join_call',
                             'chat_id': chat_id,
                             'file_path': file_path,
+                            'invite_hash': invite_hash,
                             'bitrate': bitrate,
                             'buffer_long': stream_type.stream_mode,
                             'session_id': self.pytgcalls._session_id,
                         }),
                     ),
                 )
-            except Exception:
-                raise Exception('Error internal: NOT_IN_GROUP')
+            except Exception as e:
+                raise Exception('Error internal: UNKNOWN ->', e)
         else:
             code_err = 'PYROGRAM_CLIENT_IS_NOT_RUNNING'
             if not self.pytgcalls._init_js_core:
