@@ -24,7 +24,7 @@ class UpdateCallData:
             self.pytgcalls._add_active_call(params['chat_id'])
             self.pytgcalls._add_call(chat_id)
             self.pytgcalls._set_status(chat_id, 'playing')
-        elif params['result'] == 'LEAVED_VOICE_CHAT' or \
+        elif params['result'] == 'LEFT_VOICE_CHAT' or \
                 params['result'] == 'KICKED_FROM_GROUP':
             self.pytgcalls._remove_active_call(chat_id)
             self.pytgcalls._remove_call(chat_id)
